==> tencentcloud-sdk-java-3.0.93-sources.jar: com/tencentcloudapi/ocr/v20181119/models/VatInvoiceOCRResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ocr.v20181119.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class VatInvoiceOCRResponse  extends AbstractModel{

    /**
    * 检测到的文本信息，具体内容请点击左侧链接。
    */
    @SerializedName("VatInvoiceInfos")
    @Expose
    private TextVatInvoice [] VatInvoiceInfos;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * 获取检测到的文本信息，具体内容请点击左侧链接。
     * @return VatInvoiceInfos 检测到的文本信息，具体内容请点击左侧链接。
     */
    public TextVatInvoice [] getVatInvoiceInfos() {
        return this.VatInvoiceInfos;
    }

    /**
     * 设置检测到的文本信息，具体内容请点击左侧链接。
     * @param VatInvoiceInfos 检测到的文本信息，具体内容请点击左侧链接。
     */
    public void setVatInvoiceInfos(TextVatInvoice [] VatInvoiceInfos) {
        this.VatInvoiceInfos = VatInvoiceInfos;
    }

    /**
     * 获取唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * 设置唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "VatInvoiceInfos.", this.VatInvoiceInfos);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.57-sources.jar: com/tencentcloudapi/ocr/v20181119/models/VatInvoiceOCRResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ocr.v20181119.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class VatInvoiceOCRResponse extends AbstractModel{

    /**
    * 检测到的文本信息，具体内容请点击左侧链接。
    */
    @SerializedName("VatInvoiceInfos")
    @Expose
    private TextVatInvoice [] VatInvoiceInfos;

    /**
    * 明细条目。VatInvoiceInfos中关于明细项的具体条目。
    */
    @SerializedName("Items")
    @Expose
    private VatInvoiceItem [] Items;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 检测到的文本信息，具体内容请点击左侧链接。 
     * @return VatInvoiceInfos 检测到的文本信息，具体内容请点击左侧链接。
     */
    public TextVatInvoice [] getVatInvoiceInfos() {
        return this.VatInvoiceInfos;
    }

    /**
     * Set 检测到的文本信息，具体内容请点击左侧链接。
     * @param VatInvoiceInfos 检测到的文本信息，具体内容请点击左侧链接。
     */
    public void setVatInvoiceInfos(TextVatInvoice [] VatInvoiceInfos) {
        this.VatInvoiceInfos = VatInvoiceInfos;
    }

    /**
     * Get 明细条目。VatInvoiceInfos中关于明细项的具体条目。 
     * @return Items 明细条目。VatInvoiceInfos中关于明细项的具体条目。
     */
    public VatInvoiceItem [] getItems() {
        return this.Items;
    }

    /**
     * Set 明细条目。VatInvoiceInfos中关于明细项的具体条目。
     * @param Items 明细条目。VatInvoiceInfos中关于明细项的具体条目。
     */
    public void setItems(VatInvoiceItem [] Items) {
        this.Items = Items;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "VatInvoiceInfos.", this.VatInvoiceInfos);
        this.setParamArrayObj(map, prefix + "Items.", this.Items);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
